<?php

/*
 * This file is part of the AuthStack project.
 *
 * (c) Buckhill Ltd <development@buckhill.co.uk>
 *
 * This source file is subject to the Buckhill license that is bundled
 * with this source code in the file LICENSE.
 *
 */

/*
AUTOLOADER

// composer
require __DIR__ . '/vendor/autoload.php';
*/

require __DIR__.'/../vendor/autoload.php';

use Illuminate\Database\Capsule\Manager as Capsule;

$conn = new Capsule();

$conn->addConnection([
    'driver'    => 'mysql',
    'host'      => '10.0.0.85',
    'database'  => 'authstack_test_instance',
    'username'  => 'authstack_ci_test',
    'password'  => 'authstack_ci_test',
    'charset'   => 'utf8',
    'collation' => 'utf8_unicode_ci'
]);

$conn->bootEloquent();