<?php

/*
 * This file is part of the AuthStack project.
 *
 * (c) Buckhill Ltd <development@buckhill.co.uk>
 *
 * This source file is subject to the Buckhill license that is bundled
 * with this source code in the file LICENSE.
 *
 */

namespace AuthStack\AuthProfile\Facade;

use Illuminate\Support\Facades\Facade;

class ProfileManager extends Facade
{
    protected static function getFacadeAccessor()
    {
        return 'ProfileManager';
    }
}